@@ -261,29 +261,29 @@ class CheckBoxElement(ScreenElement):
 class TableElement(ScreenElement):
     """
     class TableRowModel(object):
-        TITLE = 'tr > td:nth-child(1)'
-        WORK = 'tr > td:nth-child(2)'
-        SALARY = 'tr > td:nth-child(3)'
+        TITLE = 'td:nth-child(1)'
+        WORK = 'td:nth-child(2)'
+        SALARY = 'td:nth-child(3)'
 
         def __init__(self, container):
             self.driver = container
 
         @property
-        def title(self):
-            return self.driver.find_element_by_css_selector(self.TITLE)
+        def author(self):
+            return self.driver.find_element_by_css_selector(self.TITLE).text
 
         @property
-        def work(self):
-            return self.driver.find_element_by_css_selector(self.WORK)
+        def course(self):
+            return self.driver.find_element_by_css_selector(self.WORK).text
 
         @property
         def salary(self):
-            return self.driver.find_element_by_css_selector(self.SALARY)
+            return self.driver.find_element_by_css_selector(self.SALARY).text
     """
 
-    def __init__(self, table_body_locator, table_row_model_cls):
+    def __init__(self, table_rows_locator, table_row_model_cls):
         # noinspection PyTypeChecker
-        super(TableElement, self).__init__(locator=table_body_locator, method=ec.presence_of_all_elements_located)
+        super(TableElement, self).__init__(locator=table_rows_locator, method=ec.presence_of_all_elements_located)
         self._table_entry_cls = table_row_model_cls
 
     def __get__(self, obj, owner):
@@ -293,4 +293,7 @@ class TableElement(ScreenElement):
             condition=ec.presence_of_all_elements_located)]
         """
         self._refresh(obj)
-        return [self._table_entry_cls(table_row) for table_row in self.driver]
+        table_rows = [self._table_entry_cls(table_row) for table_row in self.driver]
+        header = table_rows[1]
+        rows = table_rows[1:]
+        return {'table_rows': table_rows, 'header': header, 'rows': rows}
