@@ -1,38 +1,20 @@
 import logging
 import os
 import sys
+import traceback
 from datetime import datetime
 from pathlib import Path
 
 from poe.utility import load_config
 
-LEVEL = 'DEBUG'
-LOG_NAME = 'log'
-STDOUT = 'False'
-WORKING_DIR = Path(os.getcwd()).parent
-config = load_config(WORKING_DIR)
-
-try:
-    if config is not None:
-        LEVEL = config['LOGGER']['level']
-        print(f'Loaded log LEVEL from config [{LEVEL}].')
-        STDOUT = config['LOGGER']['stdout']
-        print(f'Loaded STDOUT state from config [{STDOUT}].')
-        LOG_NAME = config['LOGGER']['log_name']
-        print(f'Loaded LOG_NAME from config [{LOG_NAME}].')
-        WORKING_DIR = Path(config['LOGGER']['logs_absolute_path'])
-        print(f'Loaded LOGS_ABSOLUTE_PATH from config [{WORKING_DIR}].')
-except KeyError as e:
-    print(f'{e} is not valid key or not set in [poe.ini]. Default value will be used.')
-
 
 class TestLogger(logging.Logger):
-    def __init__(self, *, folder='LOGS', log_name='log', level='INFO', stdout='False'):
+    def __init__(self, *, location_path, folder='LOGS', log_name='log', level='INFO', stdout='False'):
         super().__init__("logger")
         self.level = getattr(logging, level)
         if eval(stdout):
             self.addHandler(_StdOutHHandler(level))
-        self.addHandler(TxtFileHandler(folder=folder, log_name=log_name))
+        self.addHandler(TxtFileHandler(location_path=location_path, folder=folder, log_name=log_name))
         self.handled_element_exceptions: list[dict[
                                               str:str,
                                               str:str,
@@ -49,10 +31,10 @@ class _StdOutHHandler(logging.StreamHandler):
 
 
 class TxtFileHandler(logging.FileHandler):
-    def __init__(self, *, folder, log_name):
+    def __init__(self, *, location_path, folder, log_name):
         self.filename = f'{log_name}_{datetime.now().strftime("%d-%m-%y__%H-%M-%S")}.log'
-        (WORKING_DIR / folder).mkdir(exist_ok=True, parents=True)
-        super().__init__(str(WORKING_DIR / folder / self.filename))
+        (location_path / folder).mkdir(exist_ok=True, parents=True)
+        super().__init__(str(location_path / folder / self.filename))
         self.setFormatter(TxtFileFormatter())
 
 
@@ -88,10 +70,31 @@ class StdOutFormatter(logging.Formatter):
         return formatter.format(record)
 
 
-logger = TestLogger(log_name=LOG_NAME, level=LEVEL, stdout=STDOUT)
+LEVEL = 'DEBUG'
+LOG_NAME = 'log'
+STDOUT = 'False'
+LOGS_DIR = Path(os.getcwd())
+
+config = load_config()
+try:
+    if config is not None:
+        LEVEL = config['LOGGER']['level']
+        print(f'Loaded log LEVEL from config [{LEVEL}]')
+        STDOUT = config['LOGGER']['stdout']
+        print(f'Loaded STDOUT state from config [{STDOUT}]')
+        LOG_NAME = config['LOGGER']['log_name']
+        print(f'Loaded LOG_NAME from config [{LOG_NAME}]')
+        LOGS_DIR = Path(config['LOGGER']['logs_absolute_path'])
+        print(f'Loaded LOGS_ABSOLUTE_PATH from config [{LOGS_DIR}]')
+except KeyError as e:
+    print(f'{e} is not valid key or not set in [poe.ini]. Default value will be used.')
+except Exception as e:
+    print('\n'.join([str(e), traceback.format_exc()]))
+
+logger = TestLogger(location_path=LOGS_DIR, log_name=LOG_NAME, level=LEVEL, stdout=STDOUT)
 
 if __name__ == '__main__':
-    logger = TestLogger(folder='test-logger', stdout='True')
+    logger = TestLogger(location_path=LOGS_DIR, folder='test-logger', stdout='True')
     logger.info('test')
     logger.debug('test')
     logger.warning('test')
